@@ -232,7 +232,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -1000,8 +1000,7 @@ class Wheel(GeneratedsSuper):
         self.description = description
         self.description_nsprefix_ = None
         self.radius = radius
-        if self.radius is not None:
-            self.validate_radiusType(self.radius)
+        self.validate_radiusType(self.radius)
         self.radius_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
