@@ -231,7 +231,7 @@ except ModulenotfoundExp_ as exp:
                 try:
                     int(value)
                 except (TypeError, ValueError):
-                    raise_parse_error(node, 'Requires sequence of integer valuess')
+                    raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
             return ('%.15f' % input_data).rstrip('0')
@@ -1033,7 +1033,7 @@ class SpecialDate(GeneratedsSuper):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:pl="http://kuhlman.com/people.xsd"', name_='SpecialDate', pretty_print=True):
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='SpecialDate', pretty_print=True):
         imported_ns_def_ = GenerateDSNamespaceDefs_.get('SpecialDate')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
@@ -1060,7 +1060,7 @@ class SpecialDate(GeneratedsSuper):
         if self.SpecialProperty is not None and 'SpecialProperty' not in already_processed:
             already_processed.add('SpecialProperty')
             outfile.write(' SpecialProperty=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.SpecialProperty), input_name='SpecialProperty')), ))
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:pl="http://kuhlman.com/people.xsd"', name_='SpecialDate', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='SpecialDate', fromsubclass_=False, pretty_print=True):
         pass
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
@@ -1122,6 +1122,33 @@ class ExtremeDate(GeneratedsSuper):
         self.ExtremeProperty = ExtremeProperty
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
+    def validate_RelationType(self, value):
+        result = True
+        # Validate type RelationType, a restriction on RelationType2.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, str):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (str)' % {"value": value, "lineno": lineno, })
+                return False
+            value = value
+            enumerations = ['down', 'add']
+            if value not in enumerations:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd enumeration restriction on RelationType' % {"value" : encode_str_2_3(value), "lineno": lineno} )
+                result = False
+            value = value
+            enumerations = ['down', 'add']
+            if value not in enumerations:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd enumeration restriction on RelationType' % {"value" : encode_str_2_3(value), "lineno": lineno} )
+                result = False
+            value = value
+            enumerations = ['down', 'add']
+            if value not in enumerations:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd enumeration restriction on RelationType' % {"value" : encode_str_2_3(value), "lineno": lineno} )
+                result = False
+        return result
     def hasContent_(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
@@ -1129,7 +1156,7 @@ class ExtremeDate(GeneratedsSuper):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:pl="http://kuhlman.com/people.xsd"', name_='ExtremeDate', pretty_print=True):
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='ExtremeDate', pretty_print=True):
         imported_ns_def_ = GenerateDSNamespaceDefs_.get('ExtremeDate')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
@@ -1156,7 +1183,7 @@ class ExtremeDate(GeneratedsSuper):
         if self.ExtremeProperty is not None and 'ExtremeProperty' not in already_processed:
             already_processed.add('ExtremeProperty')
             outfile.write(' ExtremeProperty=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.ExtremeProperty), input_name='ExtremeProperty')), ))
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:pl="http://kuhlman.com/people.xsd"', name_='ExtremeDate', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='ExtremeDate', fromsubclass_=False, pretty_print=True):
         pass
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
@@ -1312,7 +1339,7 @@ def parseString(inString, silence=False, print_warnings=True):
 ##         sys.stdout.write('<?xml version="1.0" ?>\n')
 ##         rootObj.export(
 ##             sys.stdout, 0, name_=rootTag,
-##             namespacedef_='xmlns:pl="http://kuhlman.com/people.xsd"')
+##             namespacedef_='')
     if print_warnings and len(gds_collector.get_messages()) > 0:
         separator = ('-' * 50) + '\n'
         sys.stderr.write(separator)
